==> spip_4.0.4.orig.tar.xz: plugins-dist/porte_plume/lang/barreoutils_bn.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=bn
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'barre_a_accent_grave' => 'ইনসার্ট এট',
	'barre_adresse' => 'ঠিকানা',
	'barre_aide' => 'লেআউট উন্নত করার জন্য শর্টকার্ট ব্যাবহার করুন',
	'barre_alignerdroite' => '[/ডান পাশে সারিবদ্ধ করুন/] প্যারাগ্রাফ',
	'barre_ancres' => 'নোঙ্গর ব্যাবস্থাপনা',
	'barre_barre' => 'টেক্সট কেটে ফেলুন',
	'barre_bulle' => 'সাহায্যের বেলুন',
	'barre_c_cedille_maj' => 'Ç ইনসার্ট করুন',
	'barre_cadre' => 'আবদ্ধ করুন &lt;cadre&gt;টেক্সট লিখার জোন&lt;/cadre&gt;',
	'barre_caracteres' => 'বিশেষ বর্ণ',
	'barre_centrer' => '[|কেন্দ্রে সন্নিবেশ করুন|] প্যারাগ্রাফ',
	'barre_chercher' => 'খুঁজা প্রতিস্তাপন করা',
	'barre_clean' => 'কোড থেকে এইচটিএমএল ট্যাগ অপসারন করুন',
	'barre_code' => 'ফরম্যাট করুন একটি &lt;code&gt;ইনফরম্যাটিক কোডে&lt;/code&gt;',
	'barre_desindenter' => 'একটা তালিকা ডিইনডেন্ট করুন',
	'barre_e_accent_aigu' => 'É ইনসার্ট করুন',
	'barre_e_accent_grave' => 'È ইনসার্ট করুন',
	'barre_ea' => 'æ ইনসার্ট করুন',
	'barre_ea_maj' => 'Æ ইনসার্ট করুন',
	'barre_encadrer' => '[(ফ্রেমের ভেতরে আবদ্ধ করুন)] প্যারাগ্রাফ',
	'barre_eo' => 'œ ইনসার্ট করুন',
	'barre_eo_maj' => 'Œ ইনসার্ট করুন',
	'barre_euro' => '€ ইনসার্ট করুন',
	'barre_exposant' => 'টেক্সট রুপান্তরিত করুন &lt;sup&gt;exponent&lt;/sup&gt;',
	'barre_formatages_speciaux' => 'বিশেষ ফরম্যাটিং',
	'barre_galerie' => 'গ্যালারি খুলুন',
	'barre_gestion_anc_bulle' => 'নোঙ্গর সাহায্যে বেলুন',
	'barre_gestion_anc_caption' => 'সকল নোঙ্গর ব্যাবস্থাপনা',
	'barre_gestion_anc_cible' => 'নোঙ্গরের টার্গেট',
	'barre_gestion_anc_inserer' => 'নোঙ্গরে রুপান্তরিত করুন',
	'barre_gestion_anc_nom' => 'নোঙ্গরের নাম',
	'barre_gestion_anc_pointer' => 'একটি নোঙ্গরের সাথে যুক্ত করুন',
	'barre_gestion_caption' => 'লিজেন্ড এবং সারাংশ',
	'barre_gestion_colonne' => 'কলাম সংখ্যা',
	'barre_gestion_cr_casse' => 'বিচ্ছেদ মেনে চলুন',
	'barre_gestion_cr_changercasse' => 'বিচ্ছেদ পরিবর্তন করুন',
	'barre_gestion_cr_changercassemajuscules' => 'বড় হাতে লিখুন',
	'barre_gestion_cr_changercasseminuscules' => 'ছোট হাতে লিখুন',
	'barre_gestion_cr_chercher' => 'খোঁজা',
	'barre_gestion_cr_entier' => 'গোটা শব্দ',
	'barre_gestion_cr_remplacer' => 'প্রতিস্থাপন করা',
	'barre_gestion_cr_tout' => 'সবকিছু প্রতিস্থাপন করুন',
	'barre_gestion_entete' => 'হেডার',
	'barre_gestion_ligne' => 'লাইন সংখ্যা',
	'barre_gestion_taille' => 'ফিক্সড সাইজ',
	'barre_glossaire' => 'এন্ট্রি [?glossaire] (Wikipedia)',
	'barre_gras' => '{{বোল্ডে}} রুপান্তরিত করুন',
	'barre_guillemets' => '«কৌটেশন মার্কে» আবদ্ধ করুন',
	'barre_guillemets_simples' => '“দ্বিতীয় স্তরের কৌটেশন মার্কে” আবদ্ধ করুন',
	'barre_indenter' => 'একটা তালিকা ইনডেন্ট করুন',
	'barre_inserer_cadre' => 'পুর্ববিন্যাসিত কোড ইনসার্ট করুন (cadre)',
	'barre_inserer_caracteres' => 'সুনির্দিষ্ট বর্ণ ইনসার্ট করুন',
	'barre_inserer_code' => 'ইনফর্ম্যাটিক কোড ইনসার্ট করুন (code)',
	'barre_intertitre' => '{{{আন্ত-শিরোনামে}}} পরিনত করুন',
	'barre_italic' => '{ইটালিকে} পরিনত করুন',
	'barre_langue' => 'সংক্ষিপ্ত ভাষা',
	'barre_lien' => '[hypertexte link->http://...] পরিনত করুন',
	'barre_lien_externe' => 'ভহির্ভুত লিঙ্ক',
	'barre_lien_input' => 'দয়া করে আপনার লিঙ্কের ঠিকানা লিখুন (আপনি ইন্টারনেট ঠিকান লিখতে পারেন http://www.mysite.com মত, ইমেইল ঠিকানা, কিংবা শুধুমাত্র এই সাইটের আর্টিকেল নাম্বার।',
	'barre_liste_ol' => 'সংখ্যাযুক্ত তালিকায় রুপান্তরিত করুন',
	'barre_liste_ul' => 'তালিকায় রুপান্তরিত করুন',
	'barre_lorem_ipsum' => 'একটা ভুতুড়ে প্যারাগ্রাফ ইনসার্ট করুন',
	'barre_lorem_ipsum_3' => 'তিনটি ভুতুড়ে প্যারাগ্রাফ ইনসার্ট করুন',
	'barre_miseenevidence' => 'টেক্সট [*হাইলাইট*] করুন',
	'barre_note' => 'রুপান্তরিত করুন [[ফুট নৌটে]]',
	'barre_paragraphe' => 'প্যারাগ্রাফ তৈরি করুন',
	'barre_petitescapitales' => 'টেক্সট রুপান্তরিত করুন &lt;sc&gt;ছোট হাতে&lt;/sc&gt;',
	'barre_poesie' => 'একটা কবিতার আকৃতি দান করে &lt;poesie&gt;কবিতা&lt;/poesie&gt;',
	'barre_preview' => 'প্রিভিউ মোড',
	'barre_quote' => '<quote>একটি বার্তা কৌট করুন</quote>',
	'barre_stats' => 'টেক্সটের স্ট্যাটিস্টিক দেখান',
	'barre_tableau' => 'ইনসার্ট/পরিবর্তন (আগে নির্বাচিত করুন) একটা টেবিল',

	// C
	'config_info_enregistree' => 'কনফিগারেশন রক্ষিত হয়েছে',

	// E
	'editer' => 'এডিট করুন',
	'explication_barre_outils_public' => 'টুল বারের সিএসএস স্ক্রিপ্ট এবং জাভাস্ক্রিপ্ট
	(এক্সটেনশন Porte Plume) পাবলিক সাইডে লোড করা হয়
	এবং এই বারগুলো ফোরাম ফর্মে ব্যাবহার করাতে সাহায্য করে,
	crayons publics অথবা অন্যকোন প্লাগইন, যদি তাদের কনফিগুরেশন
	অনুমতি প্রদান করে।',
	'explication_barre_outils_public_2' => 'আপনি লোড না করার অপশন বেছে নিতে পারবেন
	এই স্ক্রিপ্টগুলো যাতে সাইটের পাতাগুলো হালকা হতে পারে।
	তখন থেকে ফোরাম, crayons অথবা প্লাগইনের কনফিগুরেশন যাই হোক না কেন,
	Porte Plume এর কোন টুলবার
	পাবলিক সাইটে সয়ংক্রিয়ভাবে উপস্থিত হবেনা।',

	// I
	'info_barre_outils_public' => 'পাবলিক টুলবার',
	'info_porte_plume_titre' => 'টুলবার কনফিগার করুন',

	// L
	'label_barre_outils_public_non' => 'পাবলিক সাইডে টুল বারের স্ক্রিপ্ট লোড নাকরুন',
	'label_barre_outils_public_oui' => 'পাবলিক সাইডে টুল বারের স্ক্রিপ্ট লোড করুন',

	// V
	'voir' => 'দেখুন'
);

==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/porte_plume/lang/barreoutils_bn.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=bn
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'barre_a_accent_grave' => 'ইনসার্ট এট',
	'barre_adresse' => 'ঠিকানা',
	'barre_aide' => 'লেআউট উন্নত করার জন্য শর্টকার্ট ব্যাবহার করুন',
	'barre_alignerdroite' => '[/ডান পাশে সারিবদ্ধ করুন/] প্যারাগ্রাফ',
	'barre_ancres' => 'নোঙ্গর ব্যাবস্থাপনা',
	'barre_barre' => 'টেক্সট কেটে ফেলুন',
	'barre_bulle' => 'সাহায্যের বেলুন',
	'barre_c_cedille_maj' => 'Ç ইনসার্ট করুন',
	'barre_cadre' => 'আবদ্ধ করুন &lt;cadre&gt;টেক্সট লিখার জোন&lt;/cadre&gt;',
	'barre_caracteres' => 'বিশেষ বর্ণ',
	'barre_centrer' => '[|কেন্দ্রে সন্নিবেশ করুন|] প্যারাগ্রাফ',
	'barre_chercher' => 'খুঁজা প্রতিস্তাপন করা',
	'barre_clean' => 'কোড থেকে এইচটিএমএল ট্যাগ অপসারন করুন',
	'barre_code' => 'ফরম্যাট করুন একটি &lt;code&gt;ইনফরম্যাটিক কোডে&lt;/code&gt;',
	'barre_desindenter' => 'একটা তালিকা ডিইনডেন্ট করুন',
	'barre_e_accent_aigu' => 'É ইনসার্ট করুন',
	'barre_e_accent_grave' => 'È ইনসার্ট করুন',
	'barre_ea' => 'æ ইনসার্ট করুন',
	'barre_ea_maj' => 'Æ ইনসার্ট করুন',
	'barre_encadrer' => '[(ফ্রেমের ভেতরে আবদ্ধ করুন)] প্যারাগ্রাফ',
	'barre_eo' => 'œ ইনসার্ট করুন',
	'barre_eo_maj' => 'Œ ইনসার্ট করুন',
	'barre_euro' => '€ ইনসার্ট করুন',
	'barre_exposant' => 'টেক্সট রুপান্তরিত করুন &lt;sup&gt;exponent&lt;/sup&gt;',
	'barre_formatages_speciaux' => 'বিশেষ ফরম্যাটিং',
	'barre_galerie' => 'গ্যালারি খুলুন',
	'barre_gestion_anc_bulle' => 'নোঙ্গর সাহায্যে বেলুন',
	'barre_gestion_anc_caption' => 'সকল নোঙ্গর ব্যাবস্থাপনা',
	'barre_gestion_anc_cible' => 'নোঙ্গরের টার্গেট',
	'barre_gestion_anc_inserer' => 'নোঙ্গরে রুপান্তরিত করুন',
	'barre_gestion_anc_nom' => 'নোঙ্গরের নাম',
	'barre_gestion_anc_pointer' => 'একটি নোঙ্গরের সাথে যুক্ত করুন',
	'barre_gestion_caption' => 'লিজেন্ড এবং সারাংশ',
	'barre_gestion_colonne' => 'কলাম সংখ্যা',
	'barre_gestion_cr_casse' => 'বিচ্ছেদ মেনে চলুন',
	'barre_gestion_cr_changercasse' => 'বিচ্ছেদ পরিবর্তন করুন',
	'barre_gestion_cr_changercassemajuscules' => 'বড় হাতে লিখুন',
	'barre_gestion_cr_changercasseminuscules' => 'ছোট হাতে লিখুন',
	'barre_gestion_cr_chercher' => 'খোঁজা',
	'barre_gestion_cr_entier' => 'গোটা শব্দ',
	'barre_gestion_cr_remplacer' => 'প্রতিস্থাপন করা',
	'barre_gestion_cr_tout' => 'সবকিছু প্রতিস্থাপন করুন',
	'barre_gestion_entete' => 'হেডার',
	'barre_gestion_ligne' => 'লাইন সংখ্যা',
	'barre_gestion_taille' => 'ফিক্সড সাইজ',
	'barre_glossaire' => 'এন্ট্রি [?glossaire] (Wikipedia)',
	'barre_gras' => '{{বোল্ডে}} রুপান্তরিত করুন',
	'barre_guillemets' => '«কৌটেশন মার্কে» আবদ্ধ করুন',
	'barre_guillemets_simples' => '“দ্বিতীয় স্তরের কৌটেশন মার্কে” আবদ্ধ করুন',
	'barre_indenter' => 'একটা তালিকা ইনডেন্ট করুন',
	'barre_inserer_cadre' => 'পুর্ববিন্যাসিত কোড ইনসার্ট করুন (cadre)', # MODIF
	'barre_inserer_caracteres' => 'সুনির্দিষ্ট বর্ণ ইনসার্ট করুন',
	'barre_inserer_code' => 'ইনফর্ম্যাটিক কোড ইনসার্ট করুন (code)', # MODIF
	'barre_intertitre' => '{{{আন্ত-শিরোনামে}}} পরিনত করুন',
	'barre_italic' => '{ইটালিকে} পরিনত করুন',
	'barre_langue' => 'সংক্ষিপ্ত ভাষা',
	'barre_lien' => '[hypertexte link->http://...] পরিনত করুন',
	'barre_lien_externe' => 'ভহির্ভুত লিঙ্ক',
	'barre_lien_input' => 'দয়া করে আপনার লিঙ্কের ঠিকানা লিখুন (আপনি ইন্টারনেট ঠিকান লিখতে পারেন http://www.mysite.com মত, ইমেইল ঠিকানা, কিংবা শুধুমাত্র এই সাইটের আর্টিকেল নাম্বার।',
	'barre_liste_ol' => 'সংখ্যাযুক্ত তালিকায় রুপান্তরিত করুন',
	'barre_liste_ul' => 'তালিকায় রুপান্তরিত করুন',
	'barre_lorem_ipsum' => 'একটা ভুতুড়ে প্যারাগ্রাফ ইনসার্ট করুন',
	'barre_lorem_ipsum_3' => 'তিনটি ভুতুড়ে প্যারাগ্রাফ ইনসার্ট করুন',
	'barre_miseenevidence' => 'টেক্সট [*হাইলাইট*] করুন',
	'barre_note' => 'রুপান্তরিত করুন [[ফুট নৌটে]]',
	'barre_paragraphe' => 'প্যারাগ্রাফ তৈরি করুন',
	'barre_petitescapitales' => 'টেক্সট রুপান্তরিত করুন &lt;sc&gt;ছোট হাতে&lt;/sc&gt;',
	'barre_poesie' => 'একটা কবিতার আকৃতি দান করে &lt;poesie&gt;কবিতা&lt;/poesie&gt;',
	'barre_preview' => 'প্রিভিউ মোড',
	'barre_quote' => '<quote>একটি বার্তা কৌট করুন</quote>',
	'barre_stats' => 'টেক্সটের স্ট্যাটিস্টিক দেখান',
	'barre_tableau' => 'ইনসার্ট/পরিবর্তন (আগে নির্বাচিত করুন) একটা টেবিল',

	// C
	'config_info_enregistree' => 'কনফিগারেশন রক্ষিত হয়েছে',

	// E
	'editer' => 'এডিট করুন',
	'explication_barre_outils_public' => 'টুল বারের সিএসএস স্ক্রিপ্ট এবং জাভাস্ক্রিপ্ট
	(এক্সটেনশন Porte Plume) পাবলিক সাইডে লোড করা হয়
	এবং এই বারগুলো ফোরাম ফর্মে ব্যাবহার করাতে সাহায্য করে,
	crayons publics অথবা অন্যকোন প্লাগইন, যদি তাদের কনফিগুরেশন
	অনুমতি প্রদান করে।',
	'explication_barre_outils_public_2' => 'আপনি লোড না করার অপশন বেছে নিতে পারবেন
	এই স্ক্রিপ্টগুলো যাতে সাইটের পাতাগুলো হালকা হতে পারে।
	তখন থেকে ফোরাম, crayons অথবা প্লাগইনের কনফিগুরেশন যাই হোক না কেন,
	Porte Plume এর কোন টুলবার
	পাবলিক সাইটে সয়ংক্রিয়ভাবে উপস্থিত হবেনা।',

	// I
	'info_barre_outils_public' => 'পাবলিক টুলবার',
	'info_porte_plume_titre' => 'টুলবার কনফিগার করুন',

	// L
	'label_barre_outils_public_non' => 'পাবলিক সাইডে টুল বারের স্ক্রিপ্ট লোড নাকরুন',
	'label_barre_outils_public_oui' => 'পাবলিক সাইডে টুল বারের স্ক্রিপ্ট লোড করুন',

	// V
	'voir' => 'দেখুন'
);
